@@ -65,34 +65,23 @@ open_file_destroy_cb (GtkWidget *w,
 
 
 static gboolean
-only_spaces (const char *text)
+utf8_only_spaces (const char *text)
 {
-	int l, i;
+	const char *scan;
 	
 	if (text == NULL)
 		return TRUE;
 
-	l = strlen (text);
-	for (i = 0; i < l; i++)
-		if (*text != ' ')
+	for (scan = text; *scan != 0; scan = g_utf8_next_char (scan)) {
+		gunichar c = g_utf8_get_char (scan);
+		if (! g_unichar_isspace (c))
 			return FALSE;
+	}
 
 	return TRUE;
 }
 
 
-static void
-add_files_done_cb (gpointer data)
-{
-	FRWindow *window = data;
-
-	window_pop_message (window);
-
-	visit_dir_handle_free (window->vd_handle);
-	window->vd_handle = NULL;
-}
-
-
 static int
 open_file_ok_cb (GtkWidget *w,
                  GtkWidget *file_sel)
@@ -171,16 +160,13 @@ open_file_ok_cb (GtkWidget *w,
 
 			first_path = g_build_path (G_DIR_SEPARATOR_S, base_dir, first, NULL);
 			if (path_is_dir (first_path)) {
-				window_push_message (window, _("Getting file list, wait please..."));
-				window->vd_handle = fr_archive_add_directory (
-				      window->archive, 
-				      file_name_from_path (first), 
-				      base_dir, 
-				      FALSE,
-				      window->password,
-				      window->compression,
-				      add_files_done_cb,
-				      window);
+				window_archive_add_directory (window,
+							      file_name_from_path (first), 
+							      base_dir, 
+							      FALSE,
+							      window->password,
+							      window->compression);
+
 			} else 
 				fr_archive_add (window->archive,
 						files,
@@ -201,6 +187,7 @@ open_file_ok_cb (GtkWidget *w,
 		gboolean    no_backup_files;
 		gboolean    no_dot_files;
 		gboolean    ignore_case;
+		char       *include_files;
 		const char *exclude_files;
 
 		recursive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->include_subfold_checkbutton));
@@ -212,28 +199,27 @@ open_file_ok_cb (GtkWidget *w,
 
 		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton))) {
 			exclude_files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
-			if (only_spaces (exclude_files))
+			if (utf8_only_spaces (exclude_files)) 
 				exclude_files = NULL;
 		} else
 			exclude_files = NULL;
 
-		window_push_message (window, _("Getting file list, wait please..."));
-		window->vd_handle = fr_archive_add_with_wildcard (
-			  window->archive,
-			  file_name_from_path (path),
-			  exclude_files,
-			  base_dir,
-			  update,
-			  recursive,
-			  ! no_symlinks,
-			  same_fs,
-			  no_backup_files,
-			  no_dot_files,
-			  ignore_case,
-			  window->password,
-			  window->compression,
-			  add_files_done_cb,
-			  window);
+		include_files = g_locale_to_utf8 (file_name_from_path (path), 
+						  -1, 0, 0, 0);
+		window_archive_add_with_wildcard (window,
+						  include_files,
+						  exclude_files,
+						  base_dir,
+						  update,
+						  recursive,
+						  ! no_symlinks,
+						  same_fs,
+						  no_backup_files,
+						  no_dot_files,
+						  ignore_case,
+						  window->password,
+						  window->compression);
+		g_free (include_files);
 	}
 
 	g_free (path);
@@ -603,7 +589,7 @@ load_options_ok_cb (GtkWidget *w,
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_backup_files), no_backup_files);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_dot_files), no_dot_files);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->ignore_case), ignore_case);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton), ! only_spaces (exclude_files));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton), ! utf8_only_spaces (exclude_files));
 	gtk_entry_set_text (GTK_ENTRY (data->exclude_files_entry), exclude_files);
 	
 	/**/
@@ -737,7 +723,7 @@ save_options_ok_cb (GtkWidget *w,
 	
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->exclude_files_checkbutton))) {
 		exclude_files = gtk_entry_get_text (GTK_ENTRY (data->exclude_files_entry));
-		if (only_spaces (exclude_files))
+		if (utf8_only_spaces (exclude_files))
 			exclude_files = NULL;
 	} else
 		exclude_files = NULL;
